# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class TicketQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "ticket_id": "int",
        "ticket_title": "str",
        "ticket_number": "str",
        "ticket_priority": "str",
        "ticket_impact": "str",
        "ticket_status": "str",
        "ticket_source": "str",
        "ticket_type": "str",
        "end_user_id": "int",
        "end_user_email": "str",
        "end_user_first_name": "str",
        "end_user_last_name": "str",
        "end_user_phone": "str",
        "ticket_resolved_date": "datetime",
        "ticket_created_date": "datetime",
        "technician_first_comment_date": "datetime",
        "first_response_due_date": "datetime",
        "closed_ticket_due_date": "datetime",
        "first_comment": "str",
        "last_end_user_comment": "str",
        "last_end_user_comment_timestamp": "datetime",
        "last_technician_comment": "str",
        "last_technician_comment_timestamp": "datetime",
        "on_site_duration_seconds": "int",
        "on_site_duration_minutes": "int",
        "off_site_duration_seconds": "int",
        "off_site_duration_minutes": "int",
        "on_sla_duration_seconds": "int",
        "on_sla_duration_minutes": "int",
        "off_sla_duration_seconds": "int",
        "off_sla_duration_minutes": "int",
        "total_duration_seconds": "int",
        "total_duration_minutes": "int",
        "customer_id": "int",
        "customer_name": "str",
        "customer_business_number": "str",
        "technician_contact_id": "int",
        "technician_full_name": "str",
        "technician_email": "str",
        "contract_id": "int",
    }

    attribute_map = {
        "ticket_id": "TicketID",
        "ticket_title": "TicketTitle",
        "ticket_number": "TicketNumber",
        "ticket_priority": "TicketPriority",
        "ticket_impact": "TicketImpact",
        "ticket_status": "TicketStatus",
        "ticket_source": "TicketSource",
        "ticket_type": "TicketType",
        "end_user_id": "EndUserID",
        "end_user_email": "EndUserEmail",
        "end_user_first_name": "EndUserFirstName",
        "end_user_last_name": "EndUserLastName",
        "end_user_phone": "EndUserPhone",
        "ticket_resolved_date": "TicketResolvedDate",
        "ticket_created_date": "TicketCreatedDate",
        "technician_first_comment_date": "TechnicianFirstCommentDate",
        "first_response_due_date": "FirstResponseDueDate",
        "closed_ticket_due_date": "ClosedTicketDueDate",
        "first_comment": "FirstComment",
        "last_end_user_comment": "LastEndUserComment",
        "last_end_user_comment_timestamp": "LastEndUserCommentTimestamp",
        "last_technician_comment": "LastTechnicianComment",
        "last_technician_comment_timestamp": "LastTechnicianCommentTimestamp",
        "on_site_duration_seconds": "OnSiteDurationSeconds",
        "on_site_duration_minutes": "OnSiteDurationMinutes",
        "off_site_duration_seconds": "OffSiteDurationSeconds",
        "off_site_duration_minutes": "OffSiteDurationMinutes",
        "on_sla_duration_seconds": "OnSLADurationSeconds",
        "on_sla_duration_minutes": "OnSLADurationMinutes",
        "off_sla_duration_seconds": "OffSLADurationSeconds",
        "off_sla_duration_minutes": "OffSLADurationMinutes",
        "total_duration_seconds": "TotalDurationSeconds",
        "total_duration_minutes": "TotalDurationMinutes",
        "customer_id": "CustomerID",
        "customer_name": "CustomerName",
        "customer_business_number": "CustomerBusinessNumber",
        "technician_contact_id": "TechnicianContactID",
        "technician_full_name": "TechnicianFullName",
        "technician_email": "TechnicianEmail",
        "contract_id": "ContractID",
    }

    def __init__(
        self,
        ticket_id=None,
        ticket_title=None,
        ticket_number=None,
        ticket_priority=None,
        ticket_impact=None,
        ticket_status=None,
        ticket_source=None,
        ticket_type=None,
        end_user_id=None,
        end_user_email=None,
        end_user_first_name=None,
        end_user_last_name=None,
        end_user_phone=None,
        ticket_resolved_date=None,
        ticket_created_date=None,
        technician_first_comment_date=None,
        first_response_due_date=None,
        closed_ticket_due_date=None,
        first_comment=None,
        last_end_user_comment=None,
        last_end_user_comment_timestamp=None,
        last_technician_comment=None,
        last_technician_comment_timestamp=None,
        on_site_duration_seconds=None,
        on_site_duration_minutes=None,
        off_site_duration_seconds=None,
        off_site_duration_minutes=None,
        on_sla_duration_seconds=None,
        on_sla_duration_minutes=None,
        off_sla_duration_seconds=None,
        off_sla_duration_minutes=None,
        total_duration_seconds=None,
        total_duration_minutes=None,
        customer_id=None,
        customer_name=None,
        customer_business_number=None,
        technician_contact_id=None,
        technician_full_name=None,
        technician_email=None,
        contract_id=None,
        _configuration=None,
    ):  # noqa: E501
        """TicketQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._ticket_id = None
        self._ticket_title = None
        self._ticket_number = None
        self._ticket_priority = None
        self._ticket_impact = None
        self._ticket_status = None
        self._ticket_source = None
        self._ticket_type = None
        self._end_user_id = None
        self._end_user_email = None
        self._end_user_first_name = None
        self._end_user_last_name = None
        self._end_user_phone = None
        self._ticket_resolved_date = None
        self._ticket_created_date = None
        self._technician_first_comment_date = None
        self._first_response_due_date = None
        self._closed_ticket_due_date = None
        self._first_comment = None
        self._last_end_user_comment = None
        self._last_end_user_comment_timestamp = None
        self._last_technician_comment = None
        self._last_technician_comment_timestamp = None
        self._on_site_duration_seconds = None
        self._on_site_duration_minutes = None
        self._off_site_duration_seconds = None
        self._off_site_duration_minutes = None
        self._on_sla_duration_seconds = None
        self._on_sla_duration_minutes = None
        self._off_sla_duration_seconds = None
        self._off_sla_duration_minutes = None
        self._total_duration_seconds = None
        self._total_duration_minutes = None
        self._customer_id = None
        self._customer_name = None
        self._customer_business_number = None
        self._technician_contact_id = None
        self._technician_full_name = None
        self._technician_email = None
        self._contract_id = None
        self.discriminator = None

        if ticket_id is not None:
            self.ticket_id = ticket_id
        if ticket_title is not None:
            self.ticket_title = ticket_title
        if ticket_number is not None:
            self.ticket_number = ticket_number
        if ticket_priority is not None:
            self.ticket_priority = ticket_priority
        if ticket_impact is not None:
            self.ticket_impact = ticket_impact
        if ticket_status is not None:
            self.ticket_status = ticket_status
        if ticket_source is not None:
            self.ticket_source = ticket_source
        if ticket_type is not None:
            self.ticket_type = ticket_type
        if end_user_id is not None:
            self.end_user_id = end_user_id
        if end_user_email is not None:
            self.end_user_email = end_user_email
        if end_user_first_name is not None:
            self.end_user_first_name = end_user_first_name
        if end_user_last_name is not None:
            self.end_user_last_name = end_user_last_name
        if end_user_phone is not None:
            self.end_user_phone = end_user_phone
        if ticket_resolved_date is not None:
            self.ticket_resolved_date = ticket_resolved_date
        if ticket_created_date is not None:
            self.ticket_created_date = ticket_created_date
        if technician_first_comment_date is not None:
            self.technician_first_comment_date = technician_first_comment_date
        if first_response_due_date is not None:
            self.first_response_due_date = first_response_due_date
        if closed_ticket_due_date is not None:
            self.closed_ticket_due_date = closed_ticket_due_date
        if first_comment is not None:
            self.first_comment = first_comment
        if last_end_user_comment is not None:
            self.last_end_user_comment = last_end_user_comment
        if last_end_user_comment_timestamp is not None:
            self.last_end_user_comment_timestamp = last_end_user_comment_timestamp
        if last_technician_comment is not None:
            self.last_technician_comment = last_technician_comment
        if last_technician_comment_timestamp is not None:
            self.last_technician_comment_timestamp = last_technician_comment_timestamp
        if on_site_duration_seconds is not None:
            self.on_site_duration_seconds = on_site_duration_seconds
        if on_site_duration_minutes is not None:
            self.on_site_duration_minutes = on_site_duration_minutes
        if off_site_duration_seconds is not None:
            self.off_site_duration_seconds = off_site_duration_seconds
        if off_site_duration_minutes is not None:
            self.off_site_duration_minutes = off_site_duration_minutes
        if on_sla_duration_seconds is not None:
            self.on_sla_duration_seconds = on_sla_duration_seconds
        if on_sla_duration_minutes is not None:
            self.on_sla_duration_minutes = on_sla_duration_minutes
        if off_sla_duration_seconds is not None:
            self.off_sla_duration_seconds = off_sla_duration_seconds
        if off_sla_duration_minutes is not None:
            self.off_sla_duration_minutes = off_sla_duration_minutes
        if total_duration_seconds is not None:
            self.total_duration_seconds = total_duration_seconds
        if total_duration_minutes is not None:
            self.total_duration_minutes = total_duration_minutes
        if customer_id is not None:
            self.customer_id = customer_id
        if customer_name is not None:
            self.customer_name = customer_name
        if customer_business_number is not None:
            self.customer_business_number = customer_business_number
        if technician_contact_id is not None:
            self.technician_contact_id = technician_contact_id
        if technician_full_name is not None:
            self.technician_full_name = technician_full_name
        if technician_email is not None:
            self.technician_email = technician_email
        if contract_id is not None:
            self.contract_id = contract_id

    @property
    def ticket_id(self):
        """Gets the ticket_id of this TicketQueryDTO.  # noqa: E501


        :return: The ticket_id of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._ticket_id

    @ticket_id.setter
    def ticket_id(self, ticket_id):
        """Sets the ticket_id of this TicketQueryDTO.


        :param ticket_id: The ticket_id of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._ticket_id = ticket_id

    @property
    def ticket_title(self):
        """Gets the ticket_title of this TicketQueryDTO.  # noqa: E501


        :return: The ticket_title of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_title

    @ticket_title.setter
    def ticket_title(self, ticket_title):
        """Sets the ticket_title of this TicketQueryDTO.


        :param ticket_title: The ticket_title of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._ticket_title = ticket_title

    @property
    def ticket_number(self):
        """Gets the ticket_number of this TicketQueryDTO.  # noqa: E501


        :return: The ticket_number of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_number

    @ticket_number.setter
    def ticket_number(self, ticket_number):
        """Sets the ticket_number of this TicketQueryDTO.


        :param ticket_number: The ticket_number of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._ticket_number = ticket_number

    @property
    def ticket_priority(self):
        """Gets the ticket_priority of this TicketQueryDTO.  # noqa: E501


        :return: The ticket_priority of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_priority

    @ticket_priority.setter
    def ticket_priority(self, ticket_priority):
        """Sets the ticket_priority of this TicketQueryDTO.


        :param ticket_priority: The ticket_priority of this TicketQueryDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["Low", "Medium", "High", "Critical"]  # noqa: E501
        if self._configuration.client_side_validation and ticket_priority not in allowed_values:
            raise ValueError(
                "Invalid value for `ticket_priority` ({0}), must be one of {1}".format(  # noqa: E501
                    ticket_priority, allowed_values
                )
            )

        self._ticket_priority = ticket_priority

    @property
    def ticket_impact(self):
        """Gets the ticket_impact of this TicketQueryDTO.  # noqa: E501


        :return: The ticket_impact of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_impact

    @ticket_impact.setter
    def ticket_impact(self, ticket_impact):
        """Sets the ticket_impact of this TicketQueryDTO.


        :param ticket_impact: The ticket_impact of this TicketQueryDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["NoImpact", "SiteDown", "ServerIssue", "Minor", "Major", "Crisis"]  # noqa: E501
        if self._configuration.client_side_validation and ticket_impact not in allowed_values:
            raise ValueError(
                "Invalid value for `ticket_impact` ({0}), must be one of {1}".format(  # noqa: E501
                    ticket_impact, allowed_values
                )
            )

        self._ticket_impact = ticket_impact

    @property
    def ticket_status(self):
        """Gets the ticket_status of this TicketQueryDTO.  # noqa: E501


        :return: The ticket_status of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_status

    @ticket_status.setter
    def ticket_status(self, ticket_status):
        """Sets the ticket_status of this TicketQueryDTO.


        :param ticket_status: The ticket_status of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._ticket_status = ticket_status

    @property
    def ticket_source(self):
        """Gets the ticket_source of this TicketQueryDTO.  # noqa: E501


        :return: The ticket_source of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_source

    @ticket_source.setter
    def ticket_source(self, ticket_source):
        """Sets the ticket_source of this TicketQueryDTO.


        :param ticket_source: The ticket_source of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._ticket_source = ticket_source

    @property
    def ticket_type(self):
        """Gets the ticket_type of this TicketQueryDTO.  # noqa: E501


        :return: The ticket_type of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_type

    @ticket_type.setter
    def ticket_type(self, ticket_type):
        """Sets the ticket_type of this TicketQueryDTO.


        :param ticket_type: The ticket_type of this TicketQueryDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["Incident", "Problem", "Request", "Change"]  # noqa: E501
        if self._configuration.client_side_validation and ticket_type not in allowed_values:
            raise ValueError(
                "Invalid value for `ticket_type` ({0}), must be one of {1}".format(  # noqa: E501
                    ticket_type, allowed_values
                )
            )

        self._ticket_type = ticket_type

    @property
    def end_user_id(self):
        """Gets the end_user_id of this TicketQueryDTO.  # noqa: E501


        :return: The end_user_id of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._end_user_id

    @end_user_id.setter
    def end_user_id(self, end_user_id):
        """Sets the end_user_id of this TicketQueryDTO.


        :param end_user_id: The end_user_id of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._end_user_id = end_user_id

    @property
    def end_user_email(self):
        """Gets the end_user_email of this TicketQueryDTO.  # noqa: E501


        :return: The end_user_email of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._end_user_email

    @end_user_email.setter
    def end_user_email(self, end_user_email):
        """Sets the end_user_email of this TicketQueryDTO.


        :param end_user_email: The end_user_email of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._end_user_email = end_user_email

    @property
    def end_user_first_name(self):
        """Gets the end_user_first_name of this TicketQueryDTO.  # noqa: E501


        :return: The end_user_first_name of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._end_user_first_name

    @end_user_first_name.setter
    def end_user_first_name(self, end_user_first_name):
        """Sets the end_user_first_name of this TicketQueryDTO.


        :param end_user_first_name: The end_user_first_name of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._end_user_first_name = end_user_first_name

    @property
    def end_user_last_name(self):
        """Gets the end_user_last_name of this TicketQueryDTO.  # noqa: E501


        :return: The end_user_last_name of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._end_user_last_name

    @end_user_last_name.setter
    def end_user_last_name(self, end_user_last_name):
        """Sets the end_user_last_name of this TicketQueryDTO.


        :param end_user_last_name: The end_user_last_name of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._end_user_last_name = end_user_last_name

    @property
    def end_user_phone(self):
        """Gets the end_user_phone of this TicketQueryDTO.  # noqa: E501


        :return: The end_user_phone of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._end_user_phone

    @end_user_phone.setter
    def end_user_phone(self, end_user_phone):
        """Sets the end_user_phone of this TicketQueryDTO.


        :param end_user_phone: The end_user_phone of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._end_user_phone = end_user_phone

    @property
    def ticket_resolved_date(self):
        """Gets the ticket_resolved_date of this TicketQueryDTO.  # noqa: E501


        :return: The ticket_resolved_date of this TicketQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._ticket_resolved_date

    @ticket_resolved_date.setter
    def ticket_resolved_date(self, ticket_resolved_date):
        """Sets the ticket_resolved_date of this TicketQueryDTO.


        :param ticket_resolved_date: The ticket_resolved_date of this TicketQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._ticket_resolved_date = ticket_resolved_date

    @property
    def ticket_created_date(self):
        """Gets the ticket_created_date of this TicketQueryDTO.  # noqa: E501


        :return: The ticket_created_date of this TicketQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._ticket_created_date

    @ticket_created_date.setter
    def ticket_created_date(self, ticket_created_date):
        """Sets the ticket_created_date of this TicketQueryDTO.


        :param ticket_created_date: The ticket_created_date of this TicketQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._ticket_created_date = ticket_created_date

    @property
    def technician_first_comment_date(self):
        """Gets the technician_first_comment_date of this TicketQueryDTO.  # noqa: E501


        :return: The technician_first_comment_date of this TicketQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._technician_first_comment_date

    @technician_first_comment_date.setter
    def technician_first_comment_date(self, technician_first_comment_date):
        """Sets the technician_first_comment_date of this TicketQueryDTO.


        :param technician_first_comment_date: The technician_first_comment_date of this TicketQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._technician_first_comment_date = technician_first_comment_date

    @property
    def first_response_due_date(self):
        """Gets the first_response_due_date of this TicketQueryDTO.  # noqa: E501


        :return: The first_response_due_date of this TicketQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._first_response_due_date

    @first_response_due_date.setter
    def first_response_due_date(self, first_response_due_date):
        """Sets the first_response_due_date of this TicketQueryDTO.


        :param first_response_due_date: The first_response_due_date of this TicketQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._first_response_due_date = first_response_due_date

    @property
    def closed_ticket_due_date(self):
        """Gets the closed_ticket_due_date of this TicketQueryDTO.  # noqa: E501


        :return: The closed_ticket_due_date of this TicketQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._closed_ticket_due_date

    @closed_ticket_due_date.setter
    def closed_ticket_due_date(self, closed_ticket_due_date):
        """Sets the closed_ticket_due_date of this TicketQueryDTO.


        :param closed_ticket_due_date: The closed_ticket_due_date of this TicketQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._closed_ticket_due_date = closed_ticket_due_date

    @property
    def first_comment(self):
        """Gets the first_comment of this TicketQueryDTO.  # noqa: E501


        :return: The first_comment of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._first_comment

    @first_comment.setter
    def first_comment(self, first_comment):
        """Sets the first_comment of this TicketQueryDTO.


        :param first_comment: The first_comment of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._first_comment = first_comment

    @property
    def last_end_user_comment(self):
        """Gets the last_end_user_comment of this TicketQueryDTO.  # noqa: E501


        :return: The last_end_user_comment of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._last_end_user_comment

    @last_end_user_comment.setter
    def last_end_user_comment(self, last_end_user_comment):
        """Sets the last_end_user_comment of this TicketQueryDTO.


        :param last_end_user_comment: The last_end_user_comment of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._last_end_user_comment = last_end_user_comment

    @property
    def last_end_user_comment_timestamp(self):
        """Gets the last_end_user_comment_timestamp of this TicketQueryDTO.  # noqa: E501


        :return: The last_end_user_comment_timestamp of this TicketQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._last_end_user_comment_timestamp

    @last_end_user_comment_timestamp.setter
    def last_end_user_comment_timestamp(self, last_end_user_comment_timestamp):
        """Sets the last_end_user_comment_timestamp of this TicketQueryDTO.


        :param last_end_user_comment_timestamp: The last_end_user_comment_timestamp of this TicketQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._last_end_user_comment_timestamp = last_end_user_comment_timestamp

    @property
    def last_technician_comment(self):
        """Gets the last_technician_comment of this TicketQueryDTO.  # noqa: E501


        :return: The last_technician_comment of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._last_technician_comment

    @last_technician_comment.setter
    def last_technician_comment(self, last_technician_comment):
        """Sets the last_technician_comment of this TicketQueryDTO.


        :param last_technician_comment: The last_technician_comment of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._last_technician_comment = last_technician_comment

    @property
    def last_technician_comment_timestamp(self):
        """Gets the last_technician_comment_timestamp of this TicketQueryDTO.  # noqa: E501


        :return: The last_technician_comment_timestamp of this TicketQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._last_technician_comment_timestamp

    @last_technician_comment_timestamp.setter
    def last_technician_comment_timestamp(self, last_technician_comment_timestamp):
        """Sets the last_technician_comment_timestamp of this TicketQueryDTO.


        :param last_technician_comment_timestamp: The last_technician_comment_timestamp of this TicketQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._last_technician_comment_timestamp = last_technician_comment_timestamp

    @property
    def on_site_duration_seconds(self):
        """Gets the on_site_duration_seconds of this TicketQueryDTO.  # noqa: E501


        :return: The on_site_duration_seconds of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._on_site_duration_seconds

    @on_site_duration_seconds.setter
    def on_site_duration_seconds(self, on_site_duration_seconds):
        """Sets the on_site_duration_seconds of this TicketQueryDTO.


        :param on_site_duration_seconds: The on_site_duration_seconds of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._on_site_duration_seconds = on_site_duration_seconds

    @property
    def on_site_duration_minutes(self):
        """Gets the on_site_duration_minutes of this TicketQueryDTO.  # noqa: E501


        :return: The on_site_duration_minutes of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._on_site_duration_minutes

    @on_site_duration_minutes.setter
    def on_site_duration_minutes(self, on_site_duration_minutes):
        """Sets the on_site_duration_minutes of this TicketQueryDTO.


        :param on_site_duration_minutes: The on_site_duration_minutes of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._on_site_duration_minutes = on_site_duration_minutes

    @property
    def off_site_duration_seconds(self):
        """Gets the off_site_duration_seconds of this TicketQueryDTO.  # noqa: E501


        :return: The off_site_duration_seconds of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._off_site_duration_seconds

    @off_site_duration_seconds.setter
    def off_site_duration_seconds(self, off_site_duration_seconds):
        """Sets the off_site_duration_seconds of this TicketQueryDTO.


        :param off_site_duration_seconds: The off_site_duration_seconds of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._off_site_duration_seconds = off_site_duration_seconds

    @property
    def off_site_duration_minutes(self):
        """Gets the off_site_duration_minutes of this TicketQueryDTO.  # noqa: E501


        :return: The off_site_duration_minutes of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._off_site_duration_minutes

    @off_site_duration_minutes.setter
    def off_site_duration_minutes(self, off_site_duration_minutes):
        """Sets the off_site_duration_minutes of this TicketQueryDTO.


        :param off_site_duration_minutes: The off_site_duration_minutes of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._off_site_duration_minutes = off_site_duration_minutes

    @property
    def on_sla_duration_seconds(self):
        """Gets the on_sla_duration_seconds of this TicketQueryDTO.  # noqa: E501


        :return: The on_sla_duration_seconds of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._on_sla_duration_seconds

    @on_sla_duration_seconds.setter
    def on_sla_duration_seconds(self, on_sla_duration_seconds):
        """Sets the on_sla_duration_seconds of this TicketQueryDTO.


        :param on_sla_duration_seconds: The on_sla_duration_seconds of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._on_sla_duration_seconds = on_sla_duration_seconds

    @property
    def on_sla_duration_minutes(self):
        """Gets the on_sla_duration_minutes of this TicketQueryDTO.  # noqa: E501


        :return: The on_sla_duration_minutes of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._on_sla_duration_minutes

    @on_sla_duration_minutes.setter
    def on_sla_duration_minutes(self, on_sla_duration_minutes):
        """Sets the on_sla_duration_minutes of this TicketQueryDTO.


        :param on_sla_duration_minutes: The on_sla_duration_minutes of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._on_sla_duration_minutes = on_sla_duration_minutes

    @property
    def off_sla_duration_seconds(self):
        """Gets the off_sla_duration_seconds of this TicketQueryDTO.  # noqa: E501


        :return: The off_sla_duration_seconds of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._off_sla_duration_seconds

    @off_sla_duration_seconds.setter
    def off_sla_duration_seconds(self, off_sla_duration_seconds):
        """Sets the off_sla_duration_seconds of this TicketQueryDTO.


        :param off_sla_duration_seconds: The off_sla_duration_seconds of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._off_sla_duration_seconds = off_sla_duration_seconds

    @property
    def off_sla_duration_minutes(self):
        """Gets the off_sla_duration_minutes of this TicketQueryDTO.  # noqa: E501


        :return: The off_sla_duration_minutes of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._off_sla_duration_minutes

    @off_sla_duration_minutes.setter
    def off_sla_duration_minutes(self, off_sla_duration_minutes):
        """Sets the off_sla_duration_minutes of this TicketQueryDTO.


        :param off_sla_duration_minutes: The off_sla_duration_minutes of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._off_sla_duration_minutes = off_sla_duration_minutes

    @property
    def total_duration_seconds(self):
        """Gets the total_duration_seconds of this TicketQueryDTO.  # noqa: E501


        :return: The total_duration_seconds of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._total_duration_seconds

    @total_duration_seconds.setter
    def total_duration_seconds(self, total_duration_seconds):
        """Sets the total_duration_seconds of this TicketQueryDTO.


        :param total_duration_seconds: The total_duration_seconds of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._total_duration_seconds = total_duration_seconds

    @property
    def total_duration_minutes(self):
        """Gets the total_duration_minutes of this TicketQueryDTO.  # noqa: E501


        :return: The total_duration_minutes of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._total_duration_minutes

    @total_duration_minutes.setter
    def total_duration_minutes(self, total_duration_minutes):
        """Sets the total_duration_minutes of this TicketQueryDTO.


        :param total_duration_minutes: The total_duration_minutes of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._total_duration_minutes = total_duration_minutes

    @property
    def customer_id(self):
        """Gets the customer_id of this TicketQueryDTO.  # noqa: E501


        :return: The customer_id of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this TicketQueryDTO.


        :param customer_id: The customer_id of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._customer_id = customer_id

    @property
    def customer_name(self):
        """Gets the customer_name of this TicketQueryDTO.  # noqa: E501


        :return: The customer_name of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this TicketQueryDTO.


        :param customer_name: The customer_name of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def customer_business_number(self):
        """Gets the customer_business_number of this TicketQueryDTO.  # noqa: E501


        :return: The customer_business_number of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._customer_business_number

    @customer_business_number.setter
    def customer_business_number(self, customer_business_number):
        """Sets the customer_business_number of this TicketQueryDTO.


        :param customer_business_number: The customer_business_number of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._customer_business_number = customer_business_number

    @property
    def technician_contact_id(self):
        """Gets the technician_contact_id of this TicketQueryDTO.  # noqa: E501


        :return: The technician_contact_id of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._technician_contact_id

    @technician_contact_id.setter
    def technician_contact_id(self, technician_contact_id):
        """Sets the technician_contact_id of this TicketQueryDTO.


        :param technician_contact_id: The technician_contact_id of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._technician_contact_id = technician_contact_id

    @property
    def technician_full_name(self):
        """Gets the technician_full_name of this TicketQueryDTO.  # noqa: E501


        :return: The technician_full_name of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._technician_full_name

    @technician_full_name.setter
    def technician_full_name(self, technician_full_name):
        """Sets the technician_full_name of this TicketQueryDTO.


        :param technician_full_name: The technician_full_name of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._technician_full_name = technician_full_name

    @property
    def technician_email(self):
        """Gets the technician_email of this TicketQueryDTO.  # noqa: E501


        :return: The technician_email of this TicketQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._technician_email

    @technician_email.setter
    def technician_email(self, technician_email):
        """Sets the technician_email of this TicketQueryDTO.


        :param technician_email: The technician_email of this TicketQueryDTO.  # noqa: E501
        :type: str
        """

        self._technician_email = technician_email

    @property
    def contract_id(self):
        """Gets the contract_id of this TicketQueryDTO.  # noqa: E501


        :return: The contract_id of this TicketQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._contract_id

    @contract_id.setter
    def contract_id(self, contract_id):
        """Sets the contract_id of this TicketQueryDTO.


        :param contract_id: The contract_id of this TicketQueryDTO.  # noqa: E501
        :type: int
        """

        self._contract_id = contract_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TicketQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TicketQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TicketQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class UpdateProductExpenseRateDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"category": "str", "description": "str", "amount": "float", "sku": "str", "archived": "bool"}

    attribute_map = {
        "category": "Category",
        "description": "Description",
        "amount": "Amount",
        "sku": "SKU",
        "archived": "Archived",
    }

    def __init__(
        self, category=None, description=None, amount=None, sku=None, archived=None, _configuration=None
    ):  # noqa: E501
        """UpdateProductExpenseRateDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._category = None
        self._description = None
        self._amount = None
        self._sku = None
        self._archived = None
        self.discriminator = None

        if category is not None:
            self.category = category
        if description is not None:
            self.description = description
        if amount is not None:
            self.amount = amount
        if sku is not None:
            self.sku = sku
        if archived is not None:
            self.archived = archived

    @property
    def category(self):
        """Gets the category of this UpdateProductExpenseRateDTO.  # noqa: E501


        :return: The category of this UpdateProductExpenseRateDTO.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this UpdateProductExpenseRateDTO.


        :param category: The category of this UpdateProductExpenseRateDTO.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def description(self):
        """Gets the description of this UpdateProductExpenseRateDTO.  # noqa: E501


        :return: The description of this UpdateProductExpenseRateDTO.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateProductExpenseRateDTO.


        :param description: The description of this UpdateProductExpenseRateDTO.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def amount(self):
        """Gets the amount of this UpdateProductExpenseRateDTO.  # noqa: E501


        :return: The amount of this UpdateProductExpenseRateDTO.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this UpdateProductExpenseRateDTO.


        :param amount: The amount of this UpdateProductExpenseRateDTO.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def sku(self):
        """Gets the sku of this UpdateProductExpenseRateDTO.  # noqa: E501


        :return: The sku of this UpdateProductExpenseRateDTO.  # noqa: E501
        :rtype: str
        """
        return self._sku

    @sku.setter
    def sku(self, sku):
        """Sets the sku of this UpdateProductExpenseRateDTO.


        :param sku: The sku of this UpdateProductExpenseRateDTO.  # noqa: E501
        :type: str
        """

        self._sku = sku

    @property
    def archived(self):
        """Gets the archived of this UpdateProductExpenseRateDTO.  # noqa: E501


        :return: The archived of this UpdateProductExpenseRateDTO.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this UpdateProductExpenseRateDTO.


        :param archived: The archived of this UpdateProductExpenseRateDTO.  # noqa: E501
        :type: bool
        """

        self._archived = archived

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UpdateProductExpenseRateDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateProductExpenseRateDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateProductExpenseRateDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class HourlyContractQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"primary_rate": "RateQueryDTO", "additional_rates": "list[RateQueryDTO]", "billing_period": "str"}

    attribute_map = {
        "primary_rate": "PrimaryRate",
        "additional_rates": "AdditionalRates",
        "billing_period": "BillingPeriod",
    }

    def __init__(
        self, primary_rate=None, additional_rates=None, billing_period=None, _configuration=None
    ):  # noqa: E501
        """HourlyContractQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._primary_rate = None
        self._additional_rates = None
        self._billing_period = None
        self.discriminator = None

        if primary_rate is not None:
            self.primary_rate = primary_rate
        if additional_rates is not None:
            self.additional_rates = additional_rates
        if billing_period is not None:
            self.billing_period = billing_period

    @property
    def primary_rate(self):
        """Gets the primary_rate of this HourlyContractQueryDTO.  # noqa: E501


        :return: The primary_rate of this HourlyContractQueryDTO.  # noqa: E501
        :rtype: RateQueryDTO
        """
        return self._primary_rate

    @primary_rate.setter
    def primary_rate(self, primary_rate):
        """Sets the primary_rate of this HourlyContractQueryDTO.


        :param primary_rate: The primary_rate of this HourlyContractQueryDTO.  # noqa: E501
        :type: RateQueryDTO
        """

        self._primary_rate = primary_rate

    @property
    def additional_rates(self):
        """Gets the additional_rates of this HourlyContractQueryDTO.  # noqa: E501


        :return: The additional_rates of this HourlyContractQueryDTO.  # noqa: E501
        :rtype: list[RateQueryDTO]
        """
        return self._additional_rates

    @additional_rates.setter
    def additional_rates(self, additional_rates):
        """Sets the additional_rates of this HourlyContractQueryDTO.


        :param additional_rates: The additional_rates of this HourlyContractQueryDTO.  # noqa: E501
        :type: list[RateQueryDTO]
        """

        self._additional_rates = additional_rates

    @property
    def billing_period(self):
        """Gets the billing_period of this HourlyContractQueryDTO.  # noqa: E501


        :return: The billing_period of this HourlyContractQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._billing_period

    @billing_period.setter
    def billing_period(self, billing_period):
        """Sets the billing_period of this HourlyContractQueryDTO.


        :param billing_period: The billing_period of this HourlyContractQueryDTO.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "EndOfContractDuration",
            "Weekly",
            "BiWeekly",
            "Monthly",
            "Quarterly",
            "TwiceAYear",
            "Yearly",
            "OnDemand",
        ]  # noqa: E501
        if self._configuration.client_side_validation and billing_period not in allowed_values:
            raise ValueError(
                "Invalid value for `billing_period` ({0}), must be one of {1}".format(  # noqa: E501
                    billing_period, allowed_values
                )
            )

        self._billing_period = billing_period

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(HourlyContractQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HourlyContractQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HourlyContractQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from atera_client.api_client import ApiClient


class RatesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def rates_delete_expense(self, expense_id, **kwargs):  # noqa: E501
        """Delete specified expense  # noqa: E501

        Deletes a specified expense. Requires the expense ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_delete_expense(expense_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int expense_id: Required - System Expense ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.rates_delete_expense_with_http_info(expense_id, **kwargs)  # noqa: E501
        else:
            (data) = self.rates_delete_expense_with_http_info(expense_id, **kwargs)  # noqa: E501
            return data

    def rates_delete_expense_with_http_info(self, expense_id, **kwargs):  # noqa: E501
        """Delete specified expense  # noqa: E501

        Deletes a specified expense. Requires the expense ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_delete_expense_with_http_info(expense_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int expense_id: Required - System Expense ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["expense_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method rates_delete_expense" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'expense_id' is set
        if self.api_client.client_side_validation and (
            "expense_id" not in params or params["expense_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `expense_id` when calling `rates_delete_expense`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "expense_id" in params:
            path_params["expenseId"] = params["expense_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/rates/expenses/{expenseId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def rates_delete_product(self, product_id, **kwargs):  # noqa: E501
        """Delete specified product  # noqa: E501

        Deletes a specified product. Requires the product ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_delete_product(product_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int product_id: Required - System Product ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.rates_delete_product_with_http_info(product_id, **kwargs)  # noqa: E501
        else:
            (data) = self.rates_delete_product_with_http_info(product_id, **kwargs)  # noqa: E501
            return data

    def rates_delete_product_with_http_info(self, product_id, **kwargs):  # noqa: E501
        """Delete specified product  # noqa: E501

        Deletes a specified product. Requires the product ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_delete_product_with_http_info(product_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int product_id: Required - System Product ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["product_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method rates_delete_product" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'product_id' is set
        if self.api_client.client_side_validation and (
            "product_id" not in params or params["product_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `product_id` when calling `rates_delete_product`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "product_id" in params:
            path_params["productId"] = params["product_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/rates/products/{productId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def rates_expense_query_dto(self, expense_id, **kwargs):  # noqa: E501
        """Find specified expense  # noqa: E501

        Returns a specified expense. Requires the expense ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_expense_query_dto(expense_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int expense_id: Required - System expense ID (required)
        :return: RateQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.rates_expense_query_dto_with_http_info(expense_id, **kwargs)  # noqa: E501
        else:
            (data) = self.rates_expense_query_dto_with_http_info(expense_id, **kwargs)  # noqa: E501
            return data

    def rates_expense_query_dto_with_http_info(self, expense_id, **kwargs):  # noqa: E501
        """Find specified expense  # noqa: E501

        Returns a specified expense. Requires the expense ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_expense_query_dto_with_http_info(expense_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int expense_id: Required - System expense ID (required)
        :return: RateQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["expense_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method rates_expense_query_dto" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'expense_id' is set
        if self.api_client.client_side_validation and (
            "expense_id" not in params or params["expense_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `expense_id` when calling `rates_expense_query_dto`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "expense_id" in params:
            path_params["expenseId"] = params["expense_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/rates/expenses/{expenseId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RateQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def rates_get_expenses(self, **kwargs):  # noqa: E501
        """Find expenses  # noqa: E501

        Returns a list of expenses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_get_expenses(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index, based on items per page (default is 1)
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperRateQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.rates_get_expenses_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.rates_get_expenses_with_http_info(**kwargs)  # noqa: E501
            return data

    def rates_get_expenses_with_http_info(self, **kwargs):  # noqa: E501
        """Find expenses  # noqa: E501

        Returns a list of expenses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_get_expenses_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index, based on items per page (default is 1)
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperRateQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["page", "items_in_page"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method rates_get_expenses" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/rates/expenses",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperRateQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def rates_get_products(self, **kwargs):  # noqa: E501
        """Find products  # noqa: E501

        Returns a list of products.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_get_products(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index, based on items per page (default is 1)
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperRateQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.rates_get_products_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.rates_get_products_with_http_info(**kwargs)  # noqa: E501
            return data

    def rates_get_products_with_http_info(self, **kwargs):  # noqa: E501
        """Find products  # noqa: E501

        Returns a list of products.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_get_products_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index, based on items per page (default is 1)
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperRateQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["page", "items_in_page"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method rates_get_products" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/rates/products",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperRateQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def rates_post_expense(self, expense, **kwargs):  # noqa: E501
        """Create expense  # noqa: E501

        Creates a new expense. Requires an expense description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_post_expense(expense, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateProductExpenseRateDTO expense: Required - System Expense object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.rates_post_expense_with_http_info(expense, **kwargs)  # noqa: E501
        else:
            (data) = self.rates_post_expense_with_http_info(expense, **kwargs)  # noqa: E501
            return data

    def rates_post_expense_with_http_info(self, expense, **kwargs):  # noqa: E501
        """Create expense  # noqa: E501

        Creates a new expense. Requires an expense description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_post_expense_with_http_info(expense, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateProductExpenseRateDTO expense: Required - System Expense object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["expense"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method rates_post_expense" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'expense' is set
        if self.api_client.client_side_validation and (
            "expense" not in params or params["expense"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `expense` when calling `rates_post_expense`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "expense" in params:
            body_params = params["expense"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/rates/expenses",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def rates_post_product(self, product, **kwargs):  # noqa: E501
        """Create product  # noqa: E501

        Creates a new product. Requires a product description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_post_product(product, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateProductExpenseRateDTO product: Required - System Product object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.rates_post_product_with_http_info(product, **kwargs)  # noqa: E501
        else:
            (data) = self.rates_post_product_with_http_info(product, **kwargs)  # noqa: E501
            return data

    def rates_post_product_with_http_info(self, product, **kwargs):  # noqa: E501
        """Create product  # noqa: E501

        Creates a new product. Requires a product description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_post_product_with_http_info(product, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateProductExpenseRateDTO product: Required - System Product object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["product"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method rates_post_product" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'product' is set
        if self.api_client.client_side_validation and (
            "product" not in params or params["product"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `product` when calling `rates_post_product`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "product" in params:
            body_params = params["product"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/rates/products",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def rates_product_query_dto(self, product_id, **kwargs):  # noqa: E501
        """Find specified product  # noqa: E501

        Returns a specified product. Requires the product ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_product_query_dto(product_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int product_id: Required - System product ID (required)
        :return: RateQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.rates_product_query_dto_with_http_info(product_id, **kwargs)  # noqa: E501
        else:
            (data) = self.rates_product_query_dto_with_http_info(product_id, **kwargs)  # noqa: E501
            return data

    def rates_product_query_dto_with_http_info(self, product_id, **kwargs):  # noqa: E501
        """Find specified product  # noqa: E501

        Returns a specified product. Requires the product ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_product_query_dto_with_http_info(product_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int product_id: Required - System product ID (required)
        :return: RateQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["product_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method rates_product_query_dto" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'product_id' is set
        if self.api_client.client_side_validation and (
            "product_id" not in params or params["product_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `product_id` when calling `rates_product_query_dto`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "product_id" in params:
            path_params["productId"] = params["product_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/rates/products/{productId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RateQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def rates_put_expense(self, expense_id, expense, **kwargs):  # noqa: E501
        """Update specified expense  # noqa: E501

        Updates a specified expense. Requires the expense ID.              <br /><br />               The following fields are editable:              <br /><br />               Description              <br />              Category              <br />               Amount              <br />              SKU              <br />              Archived  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_put_expense(expense_id, expense, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int expense_id: Required - System Expense ID (required)
        :param UpdateProductExpenseRateDTO expense: Required - System Expense object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.rates_put_expense_with_http_info(expense_id, expense, **kwargs)  # noqa: E501
        else:
            (data) = self.rates_put_expense_with_http_info(expense_id, expense, **kwargs)  # noqa: E501
            return data

    def rates_put_expense_with_http_info(self, expense_id, expense, **kwargs):  # noqa: E501
        """Update specified expense  # noqa: E501

        Updates a specified expense. Requires the expense ID.              <br /><br />               The following fields are editable:              <br /><br />               Description              <br />              Category              <br />               Amount              <br />              SKU              <br />              Archived  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_put_expense_with_http_info(expense_id, expense, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int expense_id: Required - System Expense ID (required)
        :param UpdateProductExpenseRateDTO expense: Required - System Expense object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["expense_id", "expense"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method rates_put_expense" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'expense_id' is set
        if self.api_client.client_side_validation and (
            "expense_id" not in params or params["expense_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `expense_id` when calling `rates_put_expense`"
            )  # noqa: E501
        # verify the required parameter 'expense' is set
        if self.api_client.client_side_validation and (
            "expense" not in params or params["expense"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `expense` when calling `rates_put_expense`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "expense_id" in params:
            path_params["expenseId"] = params["expense_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "expense" in params:
            body_params = params["expense"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/rates/expenses/{expenseId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def rates_put_product(self, product_id, product, **kwargs):  # noqa: E501
        """Update specified product  # noqa: E501

        Updates a specified product. Requires the product ID.              <br /><br />               The following fields are editable:              <br /><br />               Description              <br />              Category              <br />               Amount              <br />              SKU              <br />              Archived  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_put_product(product_id, product, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int product_id: Required - System Product ID (required)
        :param UpdateProductExpenseRateDTO product: Required - System Product object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.rates_put_product_with_http_info(product_id, product, **kwargs)  # noqa: E501
        else:
            (data) = self.rates_put_product_with_http_info(product_id, product, **kwargs)  # noqa: E501
            return data

    def rates_put_product_with_http_info(self, product_id, product, **kwargs):  # noqa: E501
        """Update specified product  # noqa: E501

        Updates a specified product. Requires the product ID.              <br /><br />               The following fields are editable:              <br /><br />               Description              <br />              Category              <br />               Amount              <br />              SKU              <br />              Archived  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rates_put_product_with_http_info(product_id, product, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int product_id: Required - System Product ID (required)
        :param UpdateProductExpenseRateDTO product: Required - System Product object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["product_id", "product"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method rates_put_product" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'product_id' is set
        if self.api_client.client_side_validation and (
            "product_id" not in params or params["product_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `product_id` when calling `rates_put_product`"
            )  # noqa: E501
        # verify the required parameter 'product' is set
        if self.api_client.client_side_validation and (
            "product" not in params or params["product"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `product` when calling `rates_put_product`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "product_id" in params:
            path_params["productId"] = params["product_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "product" in params:
            body_params = params["product"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/rates/products/{productId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class InvoiceLineItemQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "product": "str",
        "description": "str",
        "quantity": "float",
        "rate": "float",
        "tax_percentage": "float",
        "discount_percentage": "float",
        "total": "float",
        "subtotal": "float",
        "tax": "float",
        "line_idx": "int",
    }

    attribute_map = {
        "product": "Product",
        "description": "Description",
        "quantity": "Quantity",
        "rate": "Rate",
        "tax_percentage": "TaxPercentage",
        "discount_percentage": "DiscountPercentage",
        "total": "Total",
        "subtotal": "Subtotal",
        "tax": "Tax",
        "line_idx": "LineIdx",
    }

    def __init__(
        self,
        product=None,
        description=None,
        quantity=None,
        rate=None,
        tax_percentage=None,
        discount_percentage=None,
        total=None,
        subtotal=None,
        tax=None,
        line_idx=None,
        _configuration=None,
    ):  # noqa: E501
        """InvoiceLineItemQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._product = None
        self._description = None
        self._quantity = None
        self._rate = None
        self._tax_percentage = None
        self._discount_percentage = None
        self._total = None
        self._subtotal = None
        self._tax = None
        self._line_idx = None
        self.discriminator = None

        if product is not None:
            self.product = product
        if description is not None:
            self.description = description
        if quantity is not None:
            self.quantity = quantity
        if rate is not None:
            self.rate = rate
        if tax_percentage is not None:
            self.tax_percentage = tax_percentage
        if discount_percentage is not None:
            self.discount_percentage = discount_percentage
        if total is not None:
            self.total = total
        if subtotal is not None:
            self.subtotal = subtotal
        if tax is not None:
            self.tax = tax
        if line_idx is not None:
            self.line_idx = line_idx

    @property
    def product(self):
        """Gets the product of this InvoiceLineItemQueryDTO.  # noqa: E501


        :return: The product of this InvoiceLineItemQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this InvoiceLineItemQueryDTO.


        :param product: The product of this InvoiceLineItemQueryDTO.  # noqa: E501
        :type: str
        """

        self._product = product

    @property
    def description(self):
        """Gets the description of this InvoiceLineItemQueryDTO.  # noqa: E501


        :return: The description of this InvoiceLineItemQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InvoiceLineItemQueryDTO.


        :param description: The description of this InvoiceLineItemQueryDTO.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def quantity(self):
        """Gets the quantity of this InvoiceLineItemQueryDTO.  # noqa: E501


        :return: The quantity of this InvoiceLineItemQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this InvoiceLineItemQueryDTO.


        :param quantity: The quantity of this InvoiceLineItemQueryDTO.  # noqa: E501
        :type: float
        """

        self._quantity = quantity

    @property
    def rate(self):
        """Gets the rate of this InvoiceLineItemQueryDTO.  # noqa: E501


        :return: The rate of this InvoiceLineItemQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """Sets the rate of this InvoiceLineItemQueryDTO.


        :param rate: The rate of this InvoiceLineItemQueryDTO.  # noqa: E501
        :type: float
        """

        self._rate = rate

    @property
    def tax_percentage(self):
        """Gets the tax_percentage of this InvoiceLineItemQueryDTO.  # noqa: E501


        :return: The tax_percentage of this InvoiceLineItemQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._tax_percentage

    @tax_percentage.setter
    def tax_percentage(self, tax_percentage):
        """Sets the tax_percentage of this InvoiceLineItemQueryDTO.


        :param tax_percentage: The tax_percentage of this InvoiceLineItemQueryDTO.  # noqa: E501
        :type: float
        """

        self._tax_percentage = tax_percentage

    @property
    def discount_percentage(self):
        """Gets the discount_percentage of this InvoiceLineItemQueryDTO.  # noqa: E501


        :return: The discount_percentage of this InvoiceLineItemQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._discount_percentage

    @discount_percentage.setter
    def discount_percentage(self, discount_percentage):
        """Sets the discount_percentage of this InvoiceLineItemQueryDTO.


        :param discount_percentage: The discount_percentage of this InvoiceLineItemQueryDTO.  # noqa: E501
        :type: float
        """

        self._discount_percentage = discount_percentage

    @property
    def total(self):
        """Gets the total of this InvoiceLineItemQueryDTO.  # noqa: E501


        :return: The total of this InvoiceLineItemQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this InvoiceLineItemQueryDTO.


        :param total: The total of this InvoiceLineItemQueryDTO.  # noqa: E501
        :type: float
        """

        self._total = total

    @property
    def subtotal(self):
        """Gets the subtotal of this InvoiceLineItemQueryDTO.  # noqa: E501


        :return: The subtotal of this InvoiceLineItemQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._subtotal

    @subtotal.setter
    def subtotal(self, subtotal):
        """Sets the subtotal of this InvoiceLineItemQueryDTO.


        :param subtotal: The subtotal of this InvoiceLineItemQueryDTO.  # noqa: E501
        :type: float
        """

        self._subtotal = subtotal

    @property
    def tax(self):
        """Gets the tax of this InvoiceLineItemQueryDTO.  # noqa: E501


        :return: The tax of this InvoiceLineItemQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._tax

    @tax.setter
    def tax(self, tax):
        """Sets the tax of this InvoiceLineItemQueryDTO.


        :param tax: The tax of this InvoiceLineItemQueryDTO.  # noqa: E501
        :type: float
        """

        self._tax = tax

    @property
    def line_idx(self):
        """Gets the line_idx of this InvoiceLineItemQueryDTO.  # noqa: E501


        :return: The line_idx of this InvoiceLineItemQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._line_idx

    @line_idx.setter
    def line_idx(self, line_idx):
        """Sets the line_idx of this InvoiceLineItemQueryDTO.


        :param line_idx: The line_idx of this InvoiceLineItemQueryDTO.  # noqa: E501
        :type: int
        """

        self._line_idx = line_idx

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(InvoiceLineItemQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceLineItemQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InvoiceLineItemQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class CreateHttpDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "url": "str",
        "pattern": "str",
        "name": "str",
        "customer_id": "int",
        "folder_id": "int",
        "monitoring_agent_id": "int",
        "monitored": "bool",
    }

    attribute_map = {
        "url": "URL",
        "pattern": "Pattern",
        "name": "Name",
        "customer_id": "CustomerID",
        "folder_id": "FolderID",
        "monitoring_agent_id": "MonitoringAgentID",
        "monitored": "Monitored",
    }

    def __init__(
        self,
        url=None,
        pattern=None,
        name=None,
        customer_id=None,
        folder_id=None,
        monitoring_agent_id=None,
        monitored=None,
        _configuration=None,
    ):  # noqa: E501
        """CreateHttpDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._url = None
        self._pattern = None
        self._name = None
        self._customer_id = None
        self._folder_id = None
        self._monitoring_agent_id = None
        self._monitored = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if pattern is not None:
            self.pattern = pattern
        if name is not None:
            self.name = name
        if customer_id is not None:
            self.customer_id = customer_id
        if folder_id is not None:
            self.folder_id = folder_id
        if monitoring_agent_id is not None:
            self.monitoring_agent_id = monitoring_agent_id
        if monitored is not None:
            self.monitored = monitored

    @property
    def url(self):
        """Gets the url of this CreateHttpDTO.  # noqa: E501


        :return: The url of this CreateHttpDTO.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this CreateHttpDTO.


        :param url: The url of this CreateHttpDTO.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def pattern(self):
        """Gets the pattern of this CreateHttpDTO.  # noqa: E501


        :return: The pattern of this CreateHttpDTO.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this CreateHttpDTO.


        :param pattern: The pattern of this CreateHttpDTO.  # noqa: E501
        :type: str
        """

        self._pattern = pattern

    @property
    def name(self):
        """Gets the name of this CreateHttpDTO.  # noqa: E501


        :return: The name of this CreateHttpDTO.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateHttpDTO.


        :param name: The name of this CreateHttpDTO.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def customer_id(self):
        """Gets the customer_id of this CreateHttpDTO.  # noqa: E501


        :return: The customer_id of this CreateHttpDTO.  # noqa: E501
        :rtype: int
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this CreateHttpDTO.


        :param customer_id: The customer_id of this CreateHttpDTO.  # noqa: E501
        :type: int
        """

        self._customer_id = customer_id

    @property
    def folder_id(self):
        """Gets the folder_id of this CreateHttpDTO.  # noqa: E501


        :return: The folder_id of this CreateHttpDTO.  # noqa: E501
        :rtype: int
        """
        return self._folder_id

    @folder_id.setter
    def folder_id(self, folder_id):
        """Sets the folder_id of this CreateHttpDTO.


        :param folder_id: The folder_id of this CreateHttpDTO.  # noqa: E501
        :type: int
        """

        self._folder_id = folder_id

    @property
    def monitoring_agent_id(self):
        """Gets the monitoring_agent_id of this CreateHttpDTO.  # noqa: E501


        :return: The monitoring_agent_id of this CreateHttpDTO.  # noqa: E501
        :rtype: int
        """
        return self._monitoring_agent_id

    @monitoring_agent_id.setter
    def monitoring_agent_id(self, monitoring_agent_id):
        """Sets the monitoring_agent_id of this CreateHttpDTO.


        :param monitoring_agent_id: The monitoring_agent_id of this CreateHttpDTO.  # noqa: E501
        :type: int
        """

        self._monitoring_agent_id = monitoring_agent_id

    @property
    def monitored(self):
        """Gets the monitored of this CreateHttpDTO.  # noqa: E501


        :return: The monitored of this CreateHttpDTO.  # noqa: E501
        :rtype: bool
        """
        return self._monitored

    @monitored.setter
    def monitored(self, monitored):
        """Sets the monitored of this CreateHttpDTO.


        :param monitored: The monitored of this CreateHttpDTO.  # noqa: E501
        :type: bool
        """

        self._monitored = monitored

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CreateHttpDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateHttpDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateHttpDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class TcpDeviceQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "name": "str",
        "device_id": "int",
        "device_guid": "str",
        "hostname": "str",
        "customer_id": "int",
        "customer_name": "str",
        "folder_id": "int",
        "monitoring_agent_id": "int",
        "monitored": "bool",
        "ports": "list[PortQueryDTO]",
    }

    attribute_map = {
        "name": "Name",
        "device_id": "DeviceID",
        "device_guid": "DeviceGuid",
        "hostname": "Hostname",
        "customer_id": "CustomerID",
        "customer_name": "CustomerName",
        "folder_id": "FolderID",
        "monitoring_agent_id": "MonitoringAgentID",
        "monitored": "Monitored",
        "ports": "Ports",
    }

    def __init__(
        self,
        name=None,
        device_id=None,
        device_guid=None,
        hostname=None,
        customer_id=None,
        customer_name=None,
        folder_id=None,
        monitoring_agent_id=None,
        monitored=None,
        ports=None,
        _configuration=None,
    ):  # noqa: E501
        """TcpDeviceQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._device_id = None
        self._device_guid = None
        self._hostname = None
        self._customer_id = None
        self._customer_name = None
        self._folder_id = None
        self._monitoring_agent_id = None
        self._monitored = None
        self._ports = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if device_id is not None:
            self.device_id = device_id
        if device_guid is not None:
            self.device_guid = device_guid
        if hostname is not None:
            self.hostname = hostname
        if customer_id is not None:
            self.customer_id = customer_id
        if customer_name is not None:
            self.customer_name = customer_name
        if folder_id is not None:
            self.folder_id = folder_id
        if monitoring_agent_id is not None:
            self.monitoring_agent_id = monitoring_agent_id
        if monitored is not None:
            self.monitored = monitored
        if ports is not None:
            self.ports = ports

    @property
    def name(self):
        """Gets the name of this TcpDeviceQueryDTO.  # noqa: E501


        :return: The name of this TcpDeviceQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TcpDeviceQueryDTO.


        :param name: The name of this TcpDeviceQueryDTO.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def device_id(self):
        """Gets the device_id of this TcpDeviceQueryDTO.  # noqa: E501


        :return: The device_id of this TcpDeviceQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this TcpDeviceQueryDTO.


        :param device_id: The device_id of this TcpDeviceQueryDTO.  # noqa: E501
        :type: int
        """

        self._device_id = device_id

    @property
    def device_guid(self):
        """Gets the device_guid of this TcpDeviceQueryDTO.  # noqa: E501


        :return: The device_guid of this TcpDeviceQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._device_guid

    @device_guid.setter
    def device_guid(self, device_guid):
        """Sets the device_guid of this TcpDeviceQueryDTO.


        :param device_guid: The device_guid of this TcpDeviceQueryDTO.  # noqa: E501
        :type: str
        """

        self._device_guid = device_guid

    @property
    def hostname(self):
        """Gets the hostname of this TcpDeviceQueryDTO.  # noqa: E501


        :return: The hostname of this TcpDeviceQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this TcpDeviceQueryDTO.


        :param hostname: The hostname of this TcpDeviceQueryDTO.  # noqa: E501
        :type: str
        """

        self._hostname = hostname

    @property
    def customer_id(self):
        """Gets the customer_id of this TcpDeviceQueryDTO.  # noqa: E501


        :return: The customer_id of this TcpDeviceQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this TcpDeviceQueryDTO.


        :param customer_id: The customer_id of this TcpDeviceQueryDTO.  # noqa: E501
        :type: int
        """

        self._customer_id = customer_id

    @property
    def customer_name(self):
        """Gets the customer_name of this TcpDeviceQueryDTO.  # noqa: E501


        :return: The customer_name of this TcpDeviceQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this TcpDeviceQueryDTO.


        :param customer_name: The customer_name of this TcpDeviceQueryDTO.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def folder_id(self):
        """Gets the folder_id of this TcpDeviceQueryDTO.  # noqa: E501


        :return: The folder_id of this TcpDeviceQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._folder_id

    @folder_id.setter
    def folder_id(self, folder_id):
        """Sets the folder_id of this TcpDeviceQueryDTO.


        :param folder_id: The folder_id of this TcpDeviceQueryDTO.  # noqa: E501
        :type: int
        """

        self._folder_id = folder_id

    @property
    def monitoring_agent_id(self):
        """Gets the monitoring_agent_id of this TcpDeviceQueryDTO.  # noqa: E501


        :return: The monitoring_agent_id of this TcpDeviceQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._monitoring_agent_id

    @monitoring_agent_id.setter
    def monitoring_agent_id(self, monitoring_agent_id):
        """Sets the monitoring_agent_id of this TcpDeviceQueryDTO.


        :param monitoring_agent_id: The monitoring_agent_id of this TcpDeviceQueryDTO.  # noqa: E501
        :type: int
        """

        self._monitoring_agent_id = monitoring_agent_id

    @property
    def monitored(self):
        """Gets the monitored of this TcpDeviceQueryDTO.  # noqa: E501


        :return: The monitored of this TcpDeviceQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._monitored

    @monitored.setter
    def monitored(self, monitored):
        """Sets the monitored of this TcpDeviceQueryDTO.


        :param monitored: The monitored of this TcpDeviceQueryDTO.  # noqa: E501
        :type: bool
        """

        self._monitored = monitored

    @property
    def ports(self):
        """Gets the ports of this TcpDeviceQueryDTO.  # noqa: E501


        :return: The ports of this TcpDeviceQueryDTO.  # noqa: E501
        :rtype: list[PortQueryDTO]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this TcpDeviceQueryDTO.


        :param ports: The ports of this TcpDeviceQueryDTO.  # noqa: E501
        :type: list[PortQueryDTO]
        """

        self._ports = ports

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TcpDeviceQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TcpDeviceQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TcpDeviceQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class CreateContactDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "email": "str",
        "customer_id": "int",
        "customer_name": "str",
        "firstname": "str",
        "lastname": "str",
        "job_title": "str",
        "phone": "str",
        "mobile_phone": "str",
        "is_contact_person": "bool",
        "in_ignore_mode": "bool",
        "created_on": "datetime",
    }

    attribute_map = {
        "email": "Email",
        "customer_id": "CustomerID",
        "customer_name": "CustomerName",
        "firstname": "Firstname",
        "lastname": "Lastname",
        "job_title": "JobTitle",
        "phone": "Phone",
        "mobile_phone": "MobilePhone",
        "is_contact_person": "IsContactPerson",
        "in_ignore_mode": "InIgnoreMode",
        "created_on": "CreatedOn",
    }

    def __init__(
        self,
        email=None,
        customer_id=None,
        customer_name=None,
        firstname=None,
        lastname=None,
        job_title=None,
        phone=None,
        mobile_phone=None,
        is_contact_person=None,
        in_ignore_mode=None,
        created_on=None,
        _configuration=None,
    ):  # noqa: E501
        """CreateContactDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._email = None
        self._customer_id = None
        self._customer_name = None
        self._firstname = None
        self._lastname = None
        self._job_title = None
        self._phone = None
        self._mobile_phone = None
        self._is_contact_person = None
        self._in_ignore_mode = None
        self._created_on = None
        self.discriminator = None

        self.email = email
        if customer_id is not None:
            self.customer_id = customer_id
        if customer_name is not None:
            self.customer_name = customer_name
        if firstname is not None:
            self.firstname = firstname
        if lastname is not None:
            self.lastname = lastname
        if job_title is not None:
            self.job_title = job_title
        if phone is not None:
            self.phone = phone
        if mobile_phone is not None:
            self.mobile_phone = mobile_phone
        if is_contact_person is not None:
            self.is_contact_person = is_contact_person
        if in_ignore_mode is not None:
            self.in_ignore_mode = in_ignore_mode
        if created_on is not None:
            self.created_on = created_on

    @property
    def email(self):
        """Gets the email of this CreateContactDTO.  # noqa: E501


        :return: The email of this CreateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this CreateContactDTO.


        :param email: The email of this CreateContactDTO.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def customer_id(self):
        """Gets the customer_id of this CreateContactDTO.  # noqa: E501


        :return: The customer_id of this CreateContactDTO.  # noqa: E501
        :rtype: int
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this CreateContactDTO.


        :param customer_id: The customer_id of this CreateContactDTO.  # noqa: E501
        :type: int
        """

        self._customer_id = customer_id

    @property
    def customer_name(self):
        """Gets the customer_name of this CreateContactDTO.  # noqa: E501


        :return: The customer_name of this CreateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this CreateContactDTO.


        :param customer_name: The customer_name of this CreateContactDTO.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def firstname(self):
        """Gets the firstname of this CreateContactDTO.  # noqa: E501


        :return: The firstname of this CreateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._firstname

    @firstname.setter
    def firstname(self, firstname):
        """Sets the firstname of this CreateContactDTO.


        :param firstname: The firstname of this CreateContactDTO.  # noqa: E501
        :type: str
        """

        self._firstname = firstname

    @property
    def lastname(self):
        """Gets the lastname of this CreateContactDTO.  # noqa: E501


        :return: The lastname of this CreateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._lastname

    @lastname.setter
    def lastname(self, lastname):
        """Sets the lastname of this CreateContactDTO.


        :param lastname: The lastname of this CreateContactDTO.  # noqa: E501
        :type: str
        """

        self._lastname = lastname

    @property
    def job_title(self):
        """Gets the job_title of this CreateContactDTO.  # noqa: E501


        :return: The job_title of this CreateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this CreateContactDTO.


        :param job_title: The job_title of this CreateContactDTO.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def phone(self):
        """Gets the phone of this CreateContactDTO.  # noqa: E501


        :return: The phone of this CreateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this CreateContactDTO.


        :param phone: The phone of this CreateContactDTO.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def mobile_phone(self):
        """Gets the mobile_phone of this CreateContactDTO.  # noqa: E501


        :return: The mobile_phone of this CreateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._mobile_phone

    @mobile_phone.setter
    def mobile_phone(self, mobile_phone):
        """Sets the mobile_phone of this CreateContactDTO.


        :param mobile_phone: The mobile_phone of this CreateContactDTO.  # noqa: E501
        :type: str
        """

        self._mobile_phone = mobile_phone

    @property
    def is_contact_person(self):
        """Gets the is_contact_person of this CreateContactDTO.  # noqa: E501


        :return: The is_contact_person of this CreateContactDTO.  # noqa: E501
        :rtype: bool
        """
        return self._is_contact_person

    @is_contact_person.setter
    def is_contact_person(self, is_contact_person):
        """Sets the is_contact_person of this CreateContactDTO.


        :param is_contact_person: The is_contact_person of this CreateContactDTO.  # noqa: E501
        :type: bool
        """

        self._is_contact_person = is_contact_person

    @property
    def in_ignore_mode(self):
        """Gets the in_ignore_mode of this CreateContactDTO.  # noqa: E501


        :return: The in_ignore_mode of this CreateContactDTO.  # noqa: E501
        :rtype: bool
        """
        return self._in_ignore_mode

    @in_ignore_mode.setter
    def in_ignore_mode(self, in_ignore_mode):
        """Sets the in_ignore_mode of this CreateContactDTO.


        :param in_ignore_mode: The in_ignore_mode of this CreateContactDTO.  # noqa: E501
        :type: bool
        """

        self._in_ignore_mode = in_ignore_mode

    @property
    def created_on(self):
        """Gets the created_on of this CreateContactDTO.  # noqa: E501


        :return: The created_on of this CreateContactDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this CreateContactDTO.


        :param created_on: The created_on of this CreateContactDTO.  # noqa: E501
        :type: datetime
        """

        self._created_on = created_on

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CreateContactDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateContactDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateContactDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class CustomValueQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "item_id": "int",
        "id": "str",
        "field_name": "str",
        "value_as_string": "str",
        "value_as_decimal": "float",
        "value_as_date_time": "datetime",
        "value_as_bool": "bool",
    }

    attribute_map = {
        "item_id": "ItemId",
        "id": "Id",
        "field_name": "FieldName",
        "value_as_string": "ValueAsString",
        "value_as_decimal": "ValueAsDecimal",
        "value_as_date_time": "ValueAsDateTime",
        "value_as_bool": "ValueAsBool",
    }

    def __init__(
        self,
        item_id=None,
        id=None,
        field_name=None,
        value_as_string=None,
        value_as_decimal=None,
        value_as_date_time=None,
        value_as_bool=None,
        _configuration=None,
    ):  # noqa: E501
        """CustomValueQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._item_id = None
        self._id = None
        self._field_name = None
        self._value_as_string = None
        self._value_as_decimal = None
        self._value_as_date_time = None
        self._value_as_bool = None
        self.discriminator = None

        if item_id is not None:
            self.item_id = item_id
        if id is not None:
            self.id = id
        if field_name is not None:
            self.field_name = field_name
        if value_as_string is not None:
            self.value_as_string = value_as_string
        if value_as_decimal is not None:
            self.value_as_decimal = value_as_decimal
        if value_as_date_time is not None:
            self.value_as_date_time = value_as_date_time
        if value_as_bool is not None:
            self.value_as_bool = value_as_bool

    @property
    def item_id(self):
        """Gets the item_id of this CustomValueQueryDTO.  # noqa: E501


        :return: The item_id of this CustomValueQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this CustomValueQueryDTO.


        :param item_id: The item_id of this CustomValueQueryDTO.  # noqa: E501
        :type: int
        """

        self._item_id = item_id

    @property
    def id(self):
        """Gets the id of this CustomValueQueryDTO.  # noqa: E501


        :return: The id of this CustomValueQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CustomValueQueryDTO.


        :param id: The id of this CustomValueQueryDTO.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def field_name(self):
        """Gets the field_name of this CustomValueQueryDTO.  # noqa: E501


        :return: The field_name of this CustomValueQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """Sets the field_name of this CustomValueQueryDTO.


        :param field_name: The field_name of this CustomValueQueryDTO.  # noqa: E501
        :type: str
        """

        self._field_name = field_name

    @property
    def value_as_string(self):
        """Gets the value_as_string of this CustomValueQueryDTO.  # noqa: E501


        :return: The value_as_string of this CustomValueQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._value_as_string

    @value_as_string.setter
    def value_as_string(self, value_as_string):
        """Sets the value_as_string of this CustomValueQueryDTO.


        :param value_as_string: The value_as_string of this CustomValueQueryDTO.  # noqa: E501
        :type: str
        """

        self._value_as_string = value_as_string

    @property
    def value_as_decimal(self):
        """Gets the value_as_decimal of this CustomValueQueryDTO.  # noqa: E501


        :return: The value_as_decimal of this CustomValueQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._value_as_decimal

    @value_as_decimal.setter
    def value_as_decimal(self, value_as_decimal):
        """Sets the value_as_decimal of this CustomValueQueryDTO.


        :param value_as_decimal: The value_as_decimal of this CustomValueQueryDTO.  # noqa: E501
        :type: float
        """

        self._value_as_decimal = value_as_decimal

    @property
    def value_as_date_time(self):
        """Gets the value_as_date_time of this CustomValueQueryDTO.  # noqa: E501


        :return: The value_as_date_time of this CustomValueQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._value_as_date_time

    @value_as_date_time.setter
    def value_as_date_time(self, value_as_date_time):
        """Sets the value_as_date_time of this CustomValueQueryDTO.


        :param value_as_date_time: The value_as_date_time of this CustomValueQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._value_as_date_time = value_as_date_time

    @property
    def value_as_bool(self):
        """Gets the value_as_bool of this CustomValueQueryDTO.  # noqa: E501


        :return: The value_as_bool of this CustomValueQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._value_as_bool

    @value_as_bool.setter
    def value_as_bool(self, value_as_bool):
        """Sets the value_as_bool of this CustomValueQueryDTO.


        :param value_as_bool: The value_as_bool of this CustomValueQueryDTO.  # noqa: E501
        :type: bool
        """

        self._value_as_bool = value_as_bool

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CustomValueQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomValueQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CustomValueQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class ContactDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "company_name": "str",
        "contact_first_name": "str",
        "contact_last_name": "str",
        "contact_full_name": "str",
        "address": "str",
        "state": "str",
        "country": "str",
        "zip_code": "int",
        "city": "str",
        "phone": "str",
        "email": "str",
    }

    attribute_map = {
        "company_name": "CompanyName",
        "contact_first_name": "ContactFirstName",
        "contact_last_name": "ContactLastName",
        "contact_full_name": "ContactFullName",
        "address": "Address",
        "state": "State",
        "country": "Country",
        "zip_code": "ZipCode",
        "city": "City",
        "phone": "Phone",
        "email": "Email",
    }

    def __init__(
        self,
        company_name=None,
        contact_first_name=None,
        contact_last_name=None,
        contact_full_name=None,
        address=None,
        state=None,
        country=None,
        zip_code=None,
        city=None,
        phone=None,
        email=None,
        _configuration=None,
    ):  # noqa: E501
        """ContactDetails - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._company_name = None
        self._contact_first_name = None
        self._contact_last_name = None
        self._contact_full_name = None
        self._address = None
        self._state = None
        self._country = None
        self._zip_code = None
        self._city = None
        self._phone = None
        self._email = None
        self.discriminator = None

        if company_name is not None:
            self.company_name = company_name
        if contact_first_name is not None:
            self.contact_first_name = contact_first_name
        if contact_last_name is not None:
            self.contact_last_name = contact_last_name
        if contact_full_name is not None:
            self.contact_full_name = contact_full_name
        if address is not None:
            self.address = address
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if zip_code is not None:
            self.zip_code = zip_code
        if city is not None:
            self.city = city
        if phone is not None:
            self.phone = phone
        if email is not None:
            self.email = email

    @property
    def company_name(self):
        """Gets the company_name of this ContactDetails.  # noqa: E501


        :return: The company_name of this ContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this ContactDetails.


        :param company_name: The company_name of this ContactDetails.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def contact_first_name(self):
        """Gets the contact_first_name of this ContactDetails.  # noqa: E501


        :return: The contact_first_name of this ContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._contact_first_name

    @contact_first_name.setter
    def contact_first_name(self, contact_first_name):
        """Sets the contact_first_name of this ContactDetails.


        :param contact_first_name: The contact_first_name of this ContactDetails.  # noqa: E501
        :type: str
        """

        self._contact_first_name = contact_first_name

    @property
    def contact_last_name(self):
        """Gets the contact_last_name of this ContactDetails.  # noqa: E501


        :return: The contact_last_name of this ContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._contact_last_name

    @contact_last_name.setter
    def contact_last_name(self, contact_last_name):
        """Sets the contact_last_name of this ContactDetails.


        :param contact_last_name: The contact_last_name of this ContactDetails.  # noqa: E501
        :type: str
        """

        self._contact_last_name = contact_last_name

    @property
    def contact_full_name(self):
        """Gets the contact_full_name of this ContactDetails.  # noqa: E501


        :return: The contact_full_name of this ContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._contact_full_name

    @contact_full_name.setter
    def contact_full_name(self, contact_full_name):
        """Sets the contact_full_name of this ContactDetails.


        :param contact_full_name: The contact_full_name of this ContactDetails.  # noqa: E501
        :type: str
        """

        self._contact_full_name = contact_full_name

    @property
    def address(self):
        """Gets the address of this ContactDetails.  # noqa: E501


        :return: The address of this ContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this ContactDetails.


        :param address: The address of this ContactDetails.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def state(self):
        """Gets the state of this ContactDetails.  # noqa: E501


        :return: The state of this ContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ContactDetails.


        :param state: The state of this ContactDetails.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this ContactDetails.  # noqa: E501


        :return: The country of this ContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this ContactDetails.


        :param country: The country of this ContactDetails.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def zip_code(self):
        """Gets the zip_code of this ContactDetails.  # noqa: E501


        :return: The zip_code of this ContactDetails.  # noqa: E501
        :rtype: int
        """
        return self._zip_code

    @zip_code.setter
    def zip_code(self, zip_code):
        """Sets the zip_code of this ContactDetails.


        :param zip_code: The zip_code of this ContactDetails.  # noqa: E501
        :type: int
        """

        self._zip_code = zip_code

    @property
    def city(self):
        """Gets the city of this ContactDetails.  # noqa: E501


        :return: The city of this ContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this ContactDetails.


        :param city: The city of this ContactDetails.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def phone(self):
        """Gets the phone of this ContactDetails.  # noqa: E501


        :return: The phone of this ContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this ContactDetails.


        :param phone: The phone of this ContactDetails.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def email(self):
        """Gets the email of this ContactDetails.  # noqa: E501


        :return: The email of this ContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ContactDetails.


        :param email: The email of this ContactDetails.  # noqa: E501
        :type: str
        """

        self._email = email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(ContactDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContactDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ContactDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "atera-client"
VERSION = "1.1.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]
    

setup(
    name=NAME,
    version=VERSION,
    description="Welcome to the Atera API",
    author_email="roelvandenboom@inogo.nl",
    url="https://github.com/InoGo-Software/atera-client",
    keywords=["Atera", "Welcome to the Atera API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""Generated Atera API Python client."""
)



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class CustomFieldQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"name": "str", "data_type": "str", "target": "str", "possible_values": "list[OptionFieldValues]"}

    attribute_map = {"name": "Name", "data_type": "DataType", "target": "Target", "possible_values": "PossibleValues"}

    def __init__(self, name=None, data_type=None, target=None, possible_values=None, _configuration=None):  # noqa: E501
        """CustomFieldQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._data_type = None
        self._target = None
        self._possible_values = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if data_type is not None:
            self.data_type = data_type
        if target is not None:
            self.target = target
        if possible_values is not None:
            self.possible_values = possible_values

    @property
    def name(self):
        """Gets the name of this CustomFieldQueryDTO.  # noqa: E501


        :return: The name of this CustomFieldQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CustomFieldQueryDTO.


        :param name: The name of this CustomFieldQueryDTO.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def data_type(self):
        """Gets the data_type of this CustomFieldQueryDTO.  # noqa: E501


        :return: The data_type of this CustomFieldQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this CustomFieldQueryDTO.


        :param data_type: The data_type of this CustomFieldQueryDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["Text", "Boolean", "Numeric", "Date", "Options", "OptionsWithDependencies"]  # noqa: E501
        if self._configuration.client_side_validation and data_type not in allowed_values:
            raise ValueError(
                "Invalid value for `data_type` ({0}), must be one of {1}".format(  # noqa: E501
                    data_type, allowed_values
                )
            )

        self._data_type = data_type

    @property
    def target(self):
        """Gets the target of this CustomFieldQueryDTO.  # noqa: E501


        :return: The target of this CustomFieldQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this CustomFieldQueryDTO.


        :param target: The target of this CustomFieldQueryDTO.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "Customer",
            "Ticket",
            "Contact",
            "Contract",
            "SLA",
            "Agent",
            "SNMPDevice",
            "TCPDevice",
            "HTTPDevice",
            "GenericDevice",
        ]  # noqa: E501
        if self._configuration.client_side_validation and target not in allowed_values:
            raise ValueError(
                "Invalid value for `target` ({0}), must be one of {1}".format(target, allowed_values)  # noqa: E501
            )

        self._target = target

    @property
    def possible_values(self):
        """Gets the possible_values of this CustomFieldQueryDTO.  # noqa: E501


        :return: The possible_values of this CustomFieldQueryDTO.  # noqa: E501
        :rtype: list[OptionFieldValues]
        """
        return self._possible_values

    @possible_values.setter
    def possible_values(self, possible_values):
        """Sets the possible_values of this CustomFieldQueryDTO.


        :param possible_values: The possible_values of this CustomFieldQueryDTO.  # noqa: E501
        :type: list[OptionFieldValues]
        """

        self._possible_values = possible_values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CustomFieldQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomFieldQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CustomFieldQueryDTO):
            return True

        return self.to_dict() != other.to_dict()
